searchData={"items":[{"type":"extras","title":"LiveViewNative.HTML","doc":"# LiveViewNative.HTML\n\n> #### Client Spec {: .info}\n>\n> format: `:html`\n>\n> module_suffix: `HTML`\n>\n> template_sigil: `~H`\n>\n> component: `LiveViewNative.HTML.Component`","ref":"readme.html"},{"type":"extras","title":"Why? - LiveViewNative.HTML","doc":"So why is there a LiveView Native client for HTML if HTML is already supported by LiveView itself? This client\nwill enable render delegation to an HTML render component for a given LiveView, similar to how native clients\ndelegate their rendering. This allows for a consistent separation of concerns, with LiveView focused on state\nmanagement, socket connection, and event handling. Format-specific rendering can then be isolated in render\ncomponents. You don't need to use this library if you prefer the default HTML rendering in LiveView.","ref":"readme.html#why"},{"type":"extras","title":"Installation - LiveViewNative.HTML","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `live_view_native_html` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_view_native_html, \"~> 0.4.0-rc.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - LiveViewNative.HTML","doc":"Add the `HTML` plugin to your list of LiveView Native plugins:\n\n```elixir\nconfig :live_view_native, plugins: [\n  LiveViewNative.HTML\n]\n```\n\nThen in your app's `Native` module, you must add the `html` format:\n\n```elixir\ndefmodule MyAppNative do\n\n  ...\n\n  def live_view() do\n    quote do\n      use LiveViewNative.LiveView,\n        formats: [\n          :html,\n          :swiftui\n        ],\n        layouts: [\n          html: {MyAppWeb.Layouts, :app},\n          swiftui: {MyAppWeb.Layouts.SwiftUI, :app}\n        ]\n\n      unquote(verified_routes())\n    end\n  end\n\n  ...\n```\n\nYou can also re-run `mix lvn.gen`, which will generate the `Native` module based on the available LiveView Native plugins.","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - LiveViewNative.HTML","doc":"This plugin overrides the default HTML rendering behavior of a Phoenix LiveView. Instead of handling template rendering within the LiveView, the rendering is delegated to a rendering component. This follows the same rendering delegation pattern found in all LiveView Native client plugins. While LiveView itself can render HTML just fine, you may want to organize all clients, including HTML, with the same rendering pattern. This plugin allows for that.\n\n```elixir\ndefmodule MyAppWeb.HomeLive do\n  use MyAppWeb, :live_view\n  use MyAppNative, :live_view\n```\n\nThen, just like all format LiveView Native rendering components, you will create a new module namespaced under the calling module with the `module_suffix` appended:\n\n```elixir\ndefmodule MyAppWeb.HomeLive.HTML do\n  use MyAppNative, [:render_component, :html]\n```\n\nFurther details on additional options and an explanation of template rendering vs. using `render/2` are in the LiveView Native docs.\n\nHowever, instead of `~LVN`, you still use `~H` inside `render/2` functions. You will also use `.heex` as the template extension instead of `.neex`.\n\nOne advantage of using `live_view_native_html` and delegating to render components over using LiveView's in-module HTML rendering is that you get the `target` benefits from LiveView Native. This means you could opt to pass along a custom `interface` map with the `LiveSocket` connection in your `app.js`:\n\n```javascript\nlet customInterface = buildCustomInterface(); // your own custom function to populate an interface object\nlet liveSocket = new LiveSocket(\"/live\", Socket, {params: {_csrf_token: csrfToken, _interface: customInterface}});\n```\n\nNow you can use `render/2` in the render component and pattern match on custom targets or interface values. Perhaps you do some boot-time device detection to determine whether the user is on mobile or not. From our prior example, you could add the template `html/home_live+mobile.html.heex` or the function:\n\n```elixir\ndef render(assigns, %{\"target\" => \"mobile\"}) do\n   ~H\"\"\"\n     ...\n   \"\"\"\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#usage"}],"content_type":"text/markdown","proglang":"elixir","producer":{"name":"ex_doc","version":"0.36.1"}}